/* This do file produces the Online Appendix Tables in the paper. */

	clear 
	clear matrix
	set more off
		
	//USER MUST UPDATE THE PATH BELOW
	cd "/Users/niharikasingh/Dropbox/Niha Backup/RC Paper/_AER Publication Materials/Data Files/Out"
	
	* Run necessary programs 
	run "../Do/aer_programs.do"
	
	****************************************************************************
	* App Table 1 - Randomization Checks *
	****************************************************************************
			
		* Panel A and B - Village and School level checks
		
			use "../Data/aer_data_child.dta", clear

				egen stag = tag(mauzaid child_schoolid1)
				bys mauzaid: egen M_num_priv_schools = sum(stag * school_type1 == 3)
				bys mauzaid: egen M_num_gov_schools = sum(stag * school_type1 == 1)
				bys mauzaid: egen M_num_tested = sum(!mi(child_avg_theta1))
				
				cap drop mtag
				egen mtag =tag(mauzaid)
				keep if mtag == 1 
				keep  mauzaid M_num_priv_schools M_num_gov_schools  M_num_tested
								
			merge 1:m mauzaid using  "../Data/aer_data_school.dta"

				cap drop stag 
				egen stag = tag(mauzaid schoolid)
				
				replace mauza_penrolled = mauza_penrolled * 100
			
			local vars mauza_wealth mauza_numhh mauza_gini_expend M_num_gov_schools ///
				M_num_priv_schools mauza_penrolled mauza_penrolled_boys mauza_penrolled_girls ///
				mauza_schoolherf M_num_tested mauza_literacy 
		
			clear matrix 
			mat table = J(28, 2,.)
			
				* Village level 
				local row = 1
				
				foreach x of local vars {
				
					qui sum `x' if reportcard == 0 & mtag == 1 
					mat table[`row',1]=r(mean)
					
					qui reg `x' reportcard i.district if mtag == 1, r 
					mat table[`row',2]=_b[reportcard]
					mat table[`row'+1,2]=_se[reportcard]
					
					local row = `row'+2
				
				}

				* School level 
				local vars S_avg_theta1 S_fee3_comb1  S_enroll1
				
				foreach x of local vars {
				
					qui sum `x' if reportcard == 0 
					mat table[`row',1]=r(mean)
					
					qui reg `x' reportcard i.district , cluster(mauzaid)
					mat table[`row',2]=_b[reportcard]
					mat table[`row'+1,2]=_se[reportcard]
					
					local row = `row'+2
				
				}
			
			xml_tab table, save("AppendixTable1.xml") replace sheet(AppTable1_PanelAandB) ///
				showeq  ///
				cnames("Control" "Difference (Treatment - Control)") ///
				rnames("Village Wealth (Median Monthly Expenditure)" " " "Number of Households in Village" " " ///
					"Village Inequality (Gini Index)" " " "Number of Government Schools in Village" " " ///
					"Number of Private Schools in Village" " " "Village enrollment % (All)" " " ///
					"Village enrollment % (Boys)" " " "Village enrollment % (Girls)" " " ///
					"Level of Competition between Schools in Village (Herfindahl Index)" " " ///
					"No. of Grade 3 Children Testes in Village" " " "Village Adult (>24 yrs) Literacy (%)" " " ///
					"School Average Test Score" " " "School Fees" " " "Number of Students (Grades 1 to 5) Enrolled at School" " ") ///
				rblanks(0 "Panel A: Village level Variables" SCLB0, 22 "Panel B: School level Variables" SCLB0) 	

		
		* Panel C - Child level checks 
			
			use "../Data/aer_data_child.dta", clear
		
			local vars child_avg_theta1 child_female child_age1 child_dadfulledu1 child_momfulledu1 child_wealth1 

			clear matrix
			mat table = J(12, 2,.)
			
				local row = 1
				
				foreach x of local vars {
				
					qui sum `x' if reportcard == 0 & child_enrolled1 == 1
					mat table[`row',1]=r(mean)
					
					qui reg `x' reportcard i.district if child_enrolled1 == 1 , cluster(mauzaid)
					mat table[`row',2]=_b[reportcard]
					mat table[`row'+1,2]=_se[reportcard]
					
					local row = `row'+2
				
				}
			
			xml_tab table, save("AppendixTable1.xml") append sheet(AppTable1_PanelC) ///
				showeq  ///
				cnames("Control" "Difference (Treatment - Control)") ///
				rnames("Average Test Score" " " "Female Child" " " ///
					"Child Age" " " "Father's Education" " " ///
					"Mother's Education" " " "Wealth (Child Asset Index)" " ") ///
				rblanks(0 "Panel C: Child level Variables" SCLB0)

					
	****************************************************************************
	* App Table 2 - Attrition Checks *
	****************************************************************************

		use "../Data/aer_data_child", clear	
		
			* Generate appropriate variables for attrition checks
		
				keep if child_enrolled1 == 1 
		
				* Attriter - defined as being tested year 1 but not year 2
				g attrit_tested = (child_avg_theta1 != . & child_avg_theta2 == .) if child_avg_theta1!=.
				la var attrit_tested "Child tested in first but not second year"
					
				* Dropout 
				replace child_dropout2 = 0 if child_dropout2 ==.
			
				* Absent 		
				replace child_absent2 = 0 if child_absent2 ==.
		
				/* Untracked or left village - this includes all those kids who left the mauza, 
					were untracked (due to closure or promotion), and 2 kids who while enrolled 
					in the second and not absent were not tested for some reason. */
					
				egen child_other_tmp = rowtotal(child_dropout_dontknow2 child_leftmauza_unclear2) if child_enrolled2==0,m
				gen other_tmp = 1 if child_other_tmp == 0

				g child_untracked2 = (other_tmp == 1 | child_leftmauza_unclear2 == 1) | (child_absent2 == 0 & child_enrolled2==1 & child_avg_theta2==.)
				drop child_other_tmp other_tmp
		
			* Table  
		
				clear matrix
				mat t = J(21, 8,.)
				
				* Panel A - Attrition by treatment status
				qui sum attrit_tested if reportcard == 0 
				mat t[1,1]=r(mean)
				
				qui reg attrit_tested reportcard i.district, cluster(mauzaid)
				mat t[1,2]=_b[reportcard]
				mat t[2,2]=_se[reportcard]
		
				local i = 3
				
				foreach x of varlist child_absent2 child_dropout2 child_untracked2 {
					
					qui sum `x' if reportcard == 0 & attrit_tested !=.
					mat t[1,`i'] = r(mean)
					
					qui reg `x' reportcard i.district if attrit_tested !=., cluster(mauzaid)
					mat t[1,`i'+1]=_b[reportcard]
					mat t[2,`i'+1]=_se[reportcard]
					
					local i=`i'+2
					
				}
			
				* Panel B - Do attriters vary by baseline characteristics?
				local vars child_avg_theta1 child_english_theta1 child_math_theta1 child_urdu_theta1 ///
					child_female child_age1 child_momfulledu1 child_dadfulledu1 child_wealth1

				local row = 4
				
				foreach x of local vars {	

					qui sum `x' if attrit_tested == 1 & reportcard == 0 
					mat t[`row',1]=r(mean)

					qui reg `x' reportcard i.district if attrit_tested == 1, r cluster(mauzaid)
					mat t[`row',2]=_b[reportcard]
					mat t[`row'+1,2]=_se[reportcard]
				
					qui sum `x' if attrit_tested == 1 & reportcard == 0 & child_absent2 == 1
					mat t[`row',3]=r(mean)

					qui reg `x' reportcard i.district if attrit_tested == 1 & child_absent2 == 1, r cluster(mauzaid) 
					mat t[`row',4]=_b[reportcard]
					mat t[`row'+1,4]=_se[reportcard]

					qui sum `x' if attrit_tested == 1 & reportcard == 0 & child_dropout2 == 1
					mat t[`row',5]=r(mean)

					qui reg `x' reportcard i.district if attrit_tested == 1 & child_dropout2 == 1, r cluster(mauzaid)
					mat t[`row',6]=_b[reportcard]
					mat t[`row'+1,6]=_se[reportcard]

					qui sum `x' if attrit_tested == 1 & reportcard == 0 & child_untracked2 == 1
					mat t[`row',7]=r(mean)

					qui reg `x' reportcard i.district if attrit_tested == 1 & child_untracked2 == 1, r cluster(mauzaid) 
					mat t[`row',8]=_b[reportcard]
					mat t[`row'+1,8]=_se[reportcard]
			
					local row = `row'+2
					
				}
			
			xml_tab t, save("AppendixTable2.xml") replace  ///
				showeq ceq("Attriters" " " "Absentees" " " "Dropouts" " " "Untracked or Left Village" " ") ///
				cnames("Control" "Difference" "Control" "Difference" "Control" "Difference" "Control" "Difference") ///
				rnames("Report Card" " " " " "Child Average Score" " " "English Score" " " "Math Score" " " "Urdu Score" " " ///
					"Female" " " "Child Age" " " "Mother's Education" " " "Father's Education" " " "Wealth (Child Asset Index)" " ") ///
				rblanks(0 "Panel A: Attrition Check by Treatment Status" SCLB0, 3 "Panel B: Differential Attrition across Baseline Characteristics" SCLB0) 	

			
	****************************************************************************
	* App Table 3 - Perceptions Robustness *
	****************************************************************************

		use "../Data/aer_data_perceptions.dta", clear
		
			* merge in school data
			merge m:1 mauzaid schoolid using "../Data/aer_data_school.dta"
			drop if _merge == 2
		
		eststo clear 
			
			eststo, title("Preferred"): reg perc2_matched_sch perc1_matched_sch S_fee3_comb1 reportcard rc_score S_avg_theta1 $control  ///
				i.district if closed1==0 & school_merged_into2==. & stag_perc == 1, cluster(mauzaid)
				predict yhat if e(sample)
				qui sum perc1_matched_sch if yhat !=. 
				estadd scalar basemean = `r(mean)'

			eststo, title("Mixed HH Composition"): reg perc2_mixed_sch perc1_mixed_sch S_fee3_comb1 reportcard rc_score S_avg_theta1 $control  ///
				i.district if closed1==0 & school_merged_into2==. & stag_perc == 1, cluster(mauzaid)
				predict yhat2 if e(sample)
				qui sum perc1_mixed_sch if yhat2 !=. 
				estadd scalar basemean = `r(mean)'

			eststo, title("Same Respondent"): reg perc2_sameresp_sch perc1_sameresp_sch S_fee3_comb1 reportcard rc_score S_avg_theta1 $control  ///
				i.district if closed1==0 & school_merged_into2==. & stag_perc == 1, cluster(mauzaid)
				predict yhat3 if e(sample)
				qui sum perc1_sameresp_sch if yhat3 !=. 
				estadd scalar basemean = `r(mean)'

			eststo, title("Preferred"): reg perc2_ind perc1_ind S_fee3_comb1 reportcard rc_score S_avg_theta1 $control  ///
				i.district if closed1==0 & school_merged_into2==. , cluster(mauzaid)
				predict yhat4 if e(sample)
				qui sum perc1_ind if yhat4 !=. 
				estadd scalar basemean = `r(mean)'
	
		esttab using AppendixTable3.csv, b se nostar mtitles replace ///
			rename(perc1_matched_sch baseline perc1_mixed_sch baseline perc1_sameresp_sch baseline perc1_ind baseline) ///
			coeflabel(S_fee3_comb1 "Baseline Fee" reportcard "Reportcard (RC)" rc_score "RC * Score" ///
				S_avg_theta1 "Baseline School Score" baseline "Baseline Perception") ///
			mgroups("School Level" "HH x School Level" , pattern(1 0 0 1)) ///
			drop($control *dist* _cons) ///
			stats(r2 N basemean, label("R-Squared" "Observations" "Baseline Perceptions (mean)") fmt(%12.3g %12.0g %12.3g))

			
	****************************************************************************
	* App Table 4 - Test Score, Subject-wise Responses *
	****************************************************************************
		
		use "../Data/aer_data_child.dta", clear

		eststo clear
	
			* Panel A
			eststo, title("Panel A English"): reg M_english_all2 report i.district if mtag, robust
			eststo, title("Panel A Urdu"): reg M_urdu_all2 report i.district if mtag, robust
			eststo, title("Panel A Math"): reg M_math_all2 report i.district if mtag, robust	

			* Panel B
			eststo, title("Panel B English"): reg M_english_all2 report i.district M_english_all1 if mtag, robust
			eststo, title("Panel B Urdu"): reg M_urdu_all2 report i.district M_urdu_all1 if mtag, robust
			eststo, title("Panel B Math"): reg M_math_all2 report i.district M_math_all1 if mtag, robust

			* Panel C - 
			eststo, title("Panel C English"): reg M_english_all2 report i.district $control M_english_all1 if mtag, robust
				qui sum  M_english_all1 if mtag 
				estadd scalar basemean = `r(mean)'
			
			eststo, title("Panel C Urdu"): reg M_urdu_all2 report i.district $control M_urdu_all1 if mtag, robust
				qui sum  M_urdu_all1 if mtag 
				estadd scalar basemean = `r(mean)'

			eststo, title("Panel C Math"): reg M_math_all2 report i.district $control M_math_all1 if mtag, robust
				qui sum  M_math_all1 if mtag 
				estadd scalar basemean = `r(mean)'

		esttab using AppendixTable4.csv, b se nostar mtitles replace ///
			rename(M_english_all1 baseline M_urdu_all1 baseline M_math_all1 baseline) ///
			coeflabel(reportcard "Report Card" baseline "Baseline") ///
			drop($control *dist* _cons) ///
			stats(N r2 basemean, label("Observations" "R-Squared" "Baseline Test Score (mean)") fmt(%12.0g %12.3g %12.2g))
			
		/* Note that the baseline test score will be the same for all the regressions in this table
		and hence is only reported for Panel C to save space */

		
	****************************************************************************
	* App Table 5 - Village Enrollment Rate by Grades *
	****************************************************************************

		use "../Data/aer_data_school", clear
		
		eststo clear 
			
			local class Preparatory Class1 Class2 Class3 Class4 Class5
			tokenize `class'
			forval i = 1/6 {
				local j=`i'+1
				eststo, title("``i''"): reg mauza_M2_class`j' reportcard $control i.district if mtag==1, r
			}
			
		esttab using AppendixTable5.csv, b se nostar mtitles replace ///
				drop($control *dist* _cons) ///
				coeflabel(reportcard "Report Card") ///
				stats(r2 N, label("R-Squared" "Observations"))
				
	
	****************************************************************************
	* App Table 6 - Fees using diff thresholds *
	****************************************************************************
	
		
		use "../Data/aer_data_school", clear
		
		eststo clear
			
			* Village, p60
			eststo: reg S_fee3_comb2 reportcard goodpriv_M60 rc_goodpriv_M60 i.district if school_type1 == 3 , r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "None"
				f_test_gp_M60

			eststo: reg S_fee3_comb2 reportcard goodpriv_M60 rc_goodpriv_M60 i.district S_fee3_comb1 if school_type1 == 3, r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Baseline"
				f_test_gp_M60

			eststo: reg S_fee3_comb2 reportcard goodpriv_M60 rc_goodpriv_M60 i.district S_fee3_comb1 $control if school_type1 == 3, r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Village"
				f_test_gp_M60

			* Village Median
			eststo: reg S_fee3_comb2 reportcard goodpriv_M rc_goodpriv_M i.district if school_type1 == 3 , r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "None"
				f_test_4type_M

			eststo: reg S_fee3_comb2 reportcard goodpriv_M rc_goodpriv_M i.district S_fee3_comb1 if school_type1 == 3, r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Baseline"
				f_test_4type_M

			eststo: reg S_fee3_comb2 reportcard goodpriv_M rc_goodpriv_M i.district S_fee3_comb1 $control if school_type1 == 3, r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Village"
				f_test_4type_M

			* Pop Median
			eststo: reg S_fee3_comb2 reportcard goodpriv rc_goodpriv i.district if school_type1 == 3 , r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "None"
				f_test_4type

			eststo: reg S_fee3_comb2 reportcard goodpriv rc_goodpriv i.district S_fee3_comb1 if school_type1 == 3, r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Baseline"
				f_test_4type

			eststo: reg S_fee3_comb2 reportcard goodpriv rc_goodpriv i.district S_fee3_comb1 $control if school_type1 == 3, r cluster(mauzaid)
				qui sum  S_fee3_comb1 if school_type1 == 3 & S_fee3_comb2 !=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Village"
				f_test_4type

		esttab using AppendixTable6.csv, b se nostar replace ///
			mgroups("Village p60" "Village Median" "Sample Median", pattern(1 0 0 1 0 0 1 0 0)) ///
			rename(S_fee3_comb1 baseline ///
				rc_goodpriv_M rc_goodpriv rc_goodpriv_M60 rc_goodpriv ///
				goodpriv_M goodpriv goodpriv_M60 goodpriv ) ///
			coeflabel(reportcard "Report Card" goodpriv "High Scoring Private School" ///
				rc_goodpriv "RC*High Scoring Private School" baseline "Baseline Fee") ///
			drop(_cons  $control *dist*) ///
			stats(control N r2 bad_60_c bad_60_p good_60_c good_60_p basemean, ///
				label("Controls" "Observations" "R-Squared" "Low Scoring Private School" " " ///
						"High Scoring Private School" " " "Baseline Fee (mean)") ///
						layout(@ @ @ @ [@] @ [@] @)) 

						
	****************************************************************************
	* App Table 7 - Test Scores, by Child Type *
	****************************************************************************

		use "../Data/aer_data_child", clear

		global interact_child_above_60 "child_above gov_child_above goodpriv_60_child_above ngo_child_above rc_child_above rc_gov_child_above rc_goodpriv_60_child_above rc_ngo_child_above"
		global interact_child_above_S_60 "child_above_S gov_child_above_S goodpriv_60_child_above_S ngo_child_above_S rc_child_above_S rc_gov_child_above_S rc_goodpriv_60_child_above_S rc_ngo_child_above_S"

		eststo clear	
		
			eststo, title("Include Child Performance (below/above median)"): ///
				reg child_avg_theta2 reportcard $interact_4type_60 $interact_child_above_60 i.district ///
					$control child_avg_theta1, cluster(mauzaid)
				qui sum child_avg_theta1 if child_avg_theta2!=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Village"
				f_test_c_60

			eststo, title("Include Child Performance within School (below/above median)"): ///
				reg child_avg_theta2 reportcard $interact_4type_60 $interact_child_above_S_60 i.district ///
					$control child_avg_theta1, cluster(mauzaid)
				qui sum child_avg_theta1 if child_avg_theta2!=.
				estadd scalar basemean = `r(mean)'
				estadd local control "Village"
				f_test_c_S_60

		esttab using AppendixTable7.csv, b se nostar mtitles replace ///
			mgroups("Child Average Test Scores (Year 2)", pattern(1 0)) ///
			order(reportcard rc_gov rc_goodpriv_60 ///
				rc_child_above rc_gov_child_above rc_goodpriv_60_child_above ///
				rc_child_above_S rc_goodpriv_60_child_above_S rc_gov_child_above_S gov goodpriv_60)	///
			drop(*dist* $control *ngo* _cons child_above gov_child_above goodpriv_60_child_above ///
				child_above_S gov_child_above_S goodpriv_60_child_above_S) ///
			coeflabel(reportcard "Report Card (RC)" rc_gov "RC * Government School (Gov)" ///
				rc_goodpriv_60 "RC * High Scoring Private School" rc_child_above "RC * High Achieving (Ach) Student in Sample" ///
				rc_gov_child_above "RC * Gov * High Ach Student in Sample" ///
				rc_goodpriv_60_child_above "RC * High Scoring Private * High Ach Student in Sample" ///
				rc_child_above_S "RC * High Ach Student in School" ///
				rc_goodpriv_60_child_above_S "RC * High Ach Student in School * High Scoring Private Schl" ///
				rc_gov_child_above_S "RC * High Ach Student in School * Gov" ///
				gov "Government School" goodpriv_60 "High Scoring Private School" child_avg_theta1 "Baseline") ///
			stats(control N r2 ///
				bad_priv_bad_c bad_priv_bad_p bad_priv_good_c bad_priv_good_p good_priv_bad_c good_priv_bad_p ///
				good_priv_good_c good_priv_good_p gov_bad_c gov_bad_p gov_good_c gov_good_p ///
				bad_priv_badS_c bad_priv_badS_p bad_priv_goodS_c bad_priv_goodS_p good_priv_badS_c good_priv_badS_p ///
				good_priv_goodS_c good_priv_goodS_p gov_badS_c gov_badS_p gov_goodS_c gov_goodS_p, ///
				label("Controls" "Observations" "R-Squared" "Low scoring private school low ach child in sample" " " ///
				"Low scoring private school high ach child in sample" " " "High scoring private school low ach child in sample" " " ///
				"High scoring private school high ach child in sample" " " "Government school low ach child in sample" " "  ///
				"Government school high ach child in sample" " " "Low scoring private school low ach child in school" " " ///
				"Low scoring private school high ach child in school" " " "High scoring private school low ach child in school" " " ///
				"High scoring private school high ach child in school" " " "Government school low ach child in school" " "  ///
				"Government school high ach child in school" " ") /// 
				layout(@ @ @ @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @)) 

		
	****************************************************************************
	* App Table 8A - School Inputs Detailed *
	****************************************************************************

		use "../Data/aer_data_school", clear			
			
			eststo clear	
								
			* Basic infrastructure variables 
				eststo, title("Has Desk/Chair"): reg desk2 reportcard $interact_4type_60 desk1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat if e(sample)
					qui sum desk1 if yhat!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
				
				eststo, title("Class rooms per student"): reg classrooms2_perchild reportcard $interact_4type_60 school_classrooms_perstudent1  i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat2 if e(sample)
					qui sum school_classrooms_perstudent1 if yhat2!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
					
				eststo, title("Toilets per student"): reg totaltoilets2_perchild reportcard $interact_4type_60 school_toilets_perstudent1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat3 if e(sample)
					qui sum school_toilets_perstudent1 if yhat3!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
					
				eststo, title("Boards per student"): reg boards2_perchild reportcard $interact_4type_60 school_boards_perstudent1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat4 if e(sample)
					qui sum school_boards_perstudent1 if yhat4!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
							
				drop yhat*
				
			* Extra infrastructure variables 
				eststo, title("Has a Library"): reg has_library2 reportcard $interact_4type_60 has_library1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat if e(sample)
					qui sum has_library1 if yhat!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
				
				eststo, title("Has a Computer"): reg has_comp2 reportcard $interact_4type_60 has_comp1  i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat2 if e(sample)
					qui sum has_comp1 if yhat2!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
				
				eststo, title("Has a Sports Facility"): reg has_sportsfac2 reportcard $interact_4type_60 has_sportsfac1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat3 if e(sample)
					qui sum has_sportsfac1 if yhat3!=.
					estadd scalar basemean = `r(mean)'
					f_test_60

				eststo, title("Has a Wall/Fence"): reg has_wall2 reportcard $interact_4type_60 has_wall1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat4 if e(sample)
					qui sum has_wall1  if yhat4!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
				
				eststo, title("Has Fans"): reg has_fans2 reportcard $interact_4type_60 has_fans1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat5 if e(sample)
					qui sum has_fans1 if yhat5!=.
					estadd scalar basemean = `r(mean)'
					f_test_60
				
				eststo, title("Has Electricity"): reg has_electricity2 reportcard $interact_4type_60 has_electricity1 i.district $control if closed1!=1 & school_merged_into2==., cluster(mauzaid)
					predict yhat6 if e(sample)
					qui sum has_electricity1 if yhat6!=.
					estadd scalar basemean = `r(mean)'
					f_test_60

			esttab using AppendixTable8a.csv, b(3) se(4) nostar mtitles replace ///
				drop(mauza* *district _cons *ngo* ) ///	
				rename(has_electricity1 baseline has_fans1 baseline has_wall1 baseline has_sportsfac1 baseline ///
					has_comp1 baseline has_library1 baseline school_boards_perstudent1  baseline ///
					school_toilets_perstudent1 baseline school_classrooms_perstudent1 baseline desk1 baseline) ///
				coeflabel(reportcard "Report Card (RC)" gov "Gov" goodpriv_60 "High Scoring Private Schl" ///
					rc_gov "RC*Gov" rc_goodpriv_60 "RC*High Scoring Private Schl" baseline "Baseline") /// 
				mgroups("Basic Infrastructure Variables (Year 2)" "Extra Infrastructure Variables (Year 2)", pattern(1 0 0 0 1 0 0 0 0 0)) ///
				stats(r2 N bad_60_c bad_60_p good_60_c good_60_p gov_60_c gov_60_p basemean, ///					
					label("R-Squared" "Observations" "Low Scoring Private School" " " ///
						"High Scoring Private School" " " "Government School" " " "Baseline Depvar (mean)") ///
					layout(@ @ @ [@] @ [@] @ [@] @))


	***********************************************************
	* App Table 8B - Household Inputs Detailed *
	***********************************************************
			
		use "../Data/aer_data_child", clear			
	
			eststo clear
							
				eststo, title("Whether Parent Has Ever Met Class Teacher (Year 2)"): ///
					reg hh_mettr2  reportcard $interact_4type_60 hh_mettr1 ///
						$control i.district, cluster(mauzaid)
					predict yhat if e(sample)
					qui sum hh_mettr1 if yhat!=.
					estadd scalar basemean = `r(mean)'
					f_test_60

				eststo, title("Parental Knowledge of Class Teacher Name (Year 2)"): ///
					reg hh_knowtrname2 reportcard $interact_4type_60 hh_knowtrname1 ///
						$control i.district, cluster(mauzaid)
					predict yhat2 if e(sample)
					qui sum hh_knowtrname1 if yhat2!=.
					estadd scalar basemean = `r(mean)'
					f_test_60

				eststo, title("Parental Assessment of Class Teacher Involvement (Year 2)"): ///
					reg hh_trreg2 reportcard $interact_4type_60 hh_trreg1 ///
						$control i.district, cluster(mauzaid)
					predict yhat3 if e(sample)
					qui sum hh_trreg1 if yhat3!=. 
					estadd scalar basemean = `r(mean)'
					f_test_60
					
				drop yhat* 
			
			esttab using AppendixTable8b.csv, b se nostar mtitles replace ///
				drop(*ngo* *dist* $control _cons) ///
				coeflabel(reportcard "Report Card (RC)" gov "Gov" goodpriv_60 "High Scoring Private Schl" ///
					rc_gov "RC*Gov" rc_goodpriv_60 "RC*High Scoring Private Schl" baseline "Baseline") /// 
				rename(hh_trreg1 baseline hh_knowtrname1 baseline hh_mettr1 baseline) ///
				stats(r2 N bad_60_c bad_60_p good_60_c good_60_p gov_60_c gov_60_p basemean, ///					
					label("R-Squared" "Observations" "Low Scoring Private School" " " ///
						"High Scoring Private School" " " "Government School" " " "Baseline Mean (Depvar)") ///
					layout(@ @ @ [@] @ [@] @ [@] @))

	***********************************************************
	* App Table 9 - Impact by Market Heterogeneity *
	***********************************************************
		
		global interact_herf_60 "herf_high gov_herf_high goodpriv_60_herf_high ngo_herf_high rc_herf_high rc_gov_herf_high rc_goodpriv_60_herf_high rc_ngo_herf_high"
		
		use "../Data/aer_data_child", clear
			rename child_schoolid1 schoolid
			merge m:1 mauzaid schoolid using "../Data/aer_data_school.dta", keepusing(S_fee3_comb1 S_fee3_comb2) gen(_m_closed)
			cap drop stag 
			egen stag = tag(mauzaid schoolid)
			
		eststo clear
		
			eststo, title("Child Test Score (Year 2)"): reg child_avg_theta2 reportcard $interact_4type_60 $interact_herf_60 i.district ///
				child_avg_theta1 school_size1 school_edu1 school_wealth1 S_avg_theta1  child_age1 child_female $control, cluster(mauzaid)
				predict yhat if e(sample)
				qui sum child_avg_theta1 if yhat!=.
				estadd scalar basemean = `r(mean)'
				f_test_herf_type_60
				
			eststo, title("Private School Fees (Year 2)"): reg S_fee3_comb2 reportcard $interact_4type_60 $interact_herf_60 i.district ///
				S_fee3_comb1 $control if school_type1 == 3 & stag == 1, cluster(mauzaid)
				predict yhat2 if e(sample)
				qui sum S_fee3_comb1 if yhat2!=.
				estadd scalar basemean = `r(mean)'
				f_test_herf_type_60_priv
						
			drop yhat*	

		esttab using AppendixTable9.csv, b se nostar mtitles replace ///
			drop(*ngo* *dist* $control _cons school_* S_avg_theta1 child_age1 child_female herf_high ///
				gov_herf_high goodpriv_60_herf_high) ///
			rename(child_avg_theta1 baseline S_fee3_comb1 baseline) ///
			coeflabel(reportcard "Report Card (RC)" gov "Government School" goodpriv_60 "High Scoring Private School" ///
				rc_gov "RC * Government School (Gov)" rc_goodpriv_60 "RC * High Scoring Private Schl" ///
				rc_herf_high "RC * Low Competition" rc_gov_herf_high "RC * Gov * Low Competition" ///
				rc_goodpriv_60_herf_high "RC * High Scoring Priv * Low Competition" baseline "Baseline") ///
			stats(r2 N bad_priv_low_c bad_priv_low_p bad_priv_high_c bad_priv_high_p ///
					good_priv_low_c good_priv_low_p good_priv_high_c good_priv_high_p ///
					gov_low_c gov_low_p gov_high_c gov_high_p basemean, ///					
				label("R-Squared" "Observations" "Low Scoring Private School high competition" " " ///
					"Low Scoring Private School low competition" " " ///
					"High Scoring Private School high competition" " " ///
					"High Scoring Private School low competition" " " ///
					"Government School high competition" " " "Government School low competition" " " ///
					"Baseline Depvar (Mean)") ///
				layout(@ @ @ [@] @ [@] @ [@] @ [@] @ [@] @ [@] @))

